@@ -1418,8 +1418,9 @@ class DisassociateProductsFromPortfolio(PortfolioManagementTask):
                     product_id=product_view_detail.get("ProductViewSummary").get(
                         "ProductId"
                     ),
+                    manifest_file_path=self.manifest_file_path,
                 )
-            self.write_output({})
+            self.write_output(self.params_for_results_display())
 
 
 class DeleteLocalPortfolio(PortfolioManagementTask):
@@ -1449,7 +1450,7 @@ class DeleteLocalPortfolio(PortfolioManagementTask):
             region_name=self.region,
         ) as servicecatalog:
             servicecatalog.delete_portfolio(Id=self.portfolio_id)
-            self.write_output({})
+            self.write_output(self.params_for_results_display())
 
 
 class DeletePortfolioShare(PortfolioManagementTask):
@@ -1499,7 +1500,7 @@ class DeletePortfolioShare(PortfolioManagementTask):
                 servicecatalog.delete_portfolio_share(
                     PortfolioId=portfolio_id, AccountId=self.account_id,
                 )
-        self.write_output({})
+        self.write_output(self.params_for_results_display())
 
 
 class DeletePortfolio(PortfolioManagementTask):
@@ -1550,11 +1551,13 @@ class DeletePortfolio(PortfolioManagementTask):
                         account_id=self.account_id,
                         region=self.region,
                         portfolio_id=portfolio_id,
+                        manifest_file_path=self.manifest_file_path,
                     )
                     yield DeleteLocalPortfolio(
                         account_id=self.account_id,
                         region=self.region,
                         portfolio_id=portfolio_id,
+                        manifest_file_path=self.manifest_file_path,
                     )
 
             if not is_puppet_account:
@@ -1563,6 +1566,7 @@ class DeletePortfolio(PortfolioManagementTask):
                     region=self.region,
                     portfolio=self.portfolio,
                     puppet_account_id=self.puppet_account_id,
+                    manifest_file_path=self.manifest_file_path,
                 )
 
         # with betterboto_client.CrossAccountClientContextManager(
@@ -1573,7 +1577,7 @@ class DeletePortfolio(PortfolioManagementTask):
         # ) as servicecatalog:
         #     results = servicecatalog.reject_portfolio_share(PortfolioId=portfolio_id)
         #     self.write_output(results)
-        self.write_output({})
+        self.write_output(self.params_for_results_display())
 
 
 #
